@@ -43,9 +43,10 @@ class LazyHelpFormatter(HelpFormatter):
     _CHOICES_END = "}"
     _UNICODE_REPL_START = "\ufffe"  # placeholder for choice list start
     _UNICODE_REPL_END = "\uffff"  # -"- end
+    _LIST_SEP = ","
+    _UNICODE_REPL_LISTSEP = "\ufffd"  # placeholder for list separator
     _PATTERN_HEXT = re.compile(r"\(.*?\)$", re.DOTALL)
-    _PATTERN_DEFAULT = re.compile(r"(?<=default:).+?(?=\))", re.DOTALL)
-    _PATTERN_KEYWORD = re.compile(r"default|optional|required")
+    _PATTERN_DEFAULT = re.compile(r"(?<=default:).+(?=\))", re.DOTALL)
     _PATTERN_CHOICE = re.compile(
         fr"(?<=\({_CHOICES_START}|{_CHOICE_SEP} |  )"
         + fr"[^{_CHOICES_START}{_CHOICE_SEP}{_CHOICES_END}]+?"
@@ -96,9 +97,23 @@ class LazyHelpFormatter(HelpFormatter):
             s = str(c)
         s = s.replace(self._CHOICES_START, self._UNICODE_REPL_START)
         s = s.replace(self._CHOICES_END, self._UNICODE_REPL_END)
+        s = s.replace(self._CHOICE_SEP, self._UNICODE_REPL_SEP)
         s = s.replace(" ", "␣")
+        s = s.replace("\n", "␤")
+        s = s.replace("\r", "␍")
         return s
 
+    def _dstr(self, d):
+        # pylint: disable=no-self-use
+        # convert default value to string
+        if isinstance(d, (list, tuple)):
+            slist = [self._dstr(di) for di in d]
+            slist = [
+                s.replace(self._LIST_SEP, self._UNICODE_REPL_LISTSEP) for s in slist
+            ]
+            return f" {self._LIST_SEP} ".join(slist)
+        return self._cstr(d)
+
     def _format_action(self, action):
         if action.nargs == 0 and action.option_strings:
             # hack to fix length of option strings
@@ -112,13 +127,12 @@ class LazyHelpFormatter(HelpFormatter):
 
         # create formatted choice list
         if action.choices:
-            choice_strs = list(map(self._cstr, action.choices))
-            # replace separators in choices with placeholders to restore later
-            choice_strs = [
-                c.replace(self._CHOICE_SEP, self._UNICODE_REPL_SEP) for c in choice_strs
-            ]
-            # combine all the choices
-            choice_list_fmt = "{" + f" {self._CHOICE_SEP} ".join(choice_strs) + "} "
+            choice_strs = f" {self._CHOICE_SEP} ".join(
+                list(map(self._cstr, action.choices))
+            )
+            choice_list_fmt = (
+                self._CHOICES_START + choice_strs + self._CHOICES_END + " "
+            )
         else:
             choice_list_fmt = ""
 
@@ -133,7 +147,7 @@ class LazyHelpFormatter(HelpFormatter):
         elif action.default is None or action.default == SUPPRESS:
             hext = f"({choice_list_fmt}optional)"
         else:
-            hext = f"({choice_list_fmt}default: {self._cstr(action.default)})"
+            hext = f"({choice_list_fmt}default: {self._dstr(action.default)})"
 
         # combine 'base_fmt' with 'help_' and 'hext'
         fmt = base_fmt.strip("\n")
@@ -168,17 +182,42 @@ class LazyHelpFormatter(HelpFormatter):
             if def_match:
                 def_match = def_match.group(0)
                 def_match_colored = def_match.replace(self._COLOR_METAVAR("\b\b"), "")
-                def_match_colored = self._COLOR_DEFAULT(def_match_colored)
+                if isinstance(action.default, (list, tuple)):
+                    # color individual items in the sequence then join
+                    def_match_pieces = def_match_colored.split(f"{self._LIST_SEP}")
+                    def_match_pieces_colored = list(
+                        map(self._COLOR_DEFAULT, def_match_pieces)
+                    )
+                    def_match_colored = f"{self._LIST_SEP}".join(
+                        def_match_pieces_colored
+                    )
+                    def_match_colored = def_match_colored.replace(
+                        self._UNICODE_REPL_LISTSEP, self._LIST_SEP
+                    )
+                    if isinstance(action.default, list):
+                        def_match_colored = " [" + def_match_colored + " ]"
+                    else:
+                        def_match_colored = " (" + def_match_colored + " )"
+                else:
+                    def_match_colored = self._COLOR_DEFAULT(def_match_colored)
                 fmt_hext_colored = re.sub(
                     self._PATTERN_DEFAULT, def_match_colored, fmt_hext
                 )
+                fmt_hext_colored = re.sub(
+                    "default", self._COLOR_KEYWORD, fmt_hext_colored, count=1
+                )
             else:
                 fmt_hext_colored = fmt_hext
 
             # color keywords
-            fmt_hext_colored = re.sub(
-                self._PATTERN_KEYWORD, self._COLOR_KEYWORD, fmt_hext_colored
-            )
+            if action.required:
+                fmt_hext_colored = self._COLOR_KEYWORD("required").join(
+                    fmt_hext_colored.rsplit("required", 1)
+                )
+            elif action.default is None or action.default == SUPPRESS:
+                fmt_hext_colored = self._COLOR_KEYWORD("optional").join(
+                    fmt_hext_colored.rsplit("optional", 1)
+                )
 
             # color choices
             fmt_hext_colored = re.sub(
@@ -290,7 +329,9 @@ def comma_separated_ints(string: str) -> List[int]:
     try:
         return list(map(int, string.split(",")))
     except:
-        raise ArgumentTypeError(f"`{string}` is not a comma separated list of ints")
+        raise ArgumentTypeError(
+            f"`{string}` is not a comma separated list of ints"
+        ) from None
 
 
 class CommaSeparatedInts:
@@ -301,7 +342,9 @@ class CommaSeparatedInts:
         try:
             return list(map(int, string.split(",")))
         except:
-            raise ArgumentTypeError(f"`{string}` is not a comma separated list of ints")
+            raise ArgumentTypeError(
+                f"`{string}` is not a comma separated list of ints"
+            ) from None
 
 
 class InputFileType(FileType):
@@ -346,7 +389,7 @@ class OutputFileType(FileType):
             try:
                 os.makedirs(file_dir)
             except Exception as e:
-                raise ArgumentTypeError(f"could not create {file_dir}: {e}")
+                raise ArgumentTypeError(f"could not create {file_dir}") from e
             logging.info(f"created {file_dir}")
         return super().__call__(string)
 
@@ -373,7 +416,7 @@ class OutputDirectoryType:
             try:
                 os.makedirs(string)
             except Exception as e:
-                raise ArgumentTypeError(f"cound not create {string}: {e}")
+                raise ArgumentTypeError(f"cound not create {string}") from e
             logging.info(f"created {string}")
         elif not os.path.isdir(string):
             raise ArgumentTypeError(f"{string} is a file: expected directory")
@@ -397,7 +440,7 @@ class ClassType(Generic[T]):
             choices = [f"'{c}'" for c in get_subclass_names(self.cls)]
             raise ArgumentTypeError(
                 f"invalid choice: '{string}' " f"(choose from {', '.join(choices)})"
-            )
+            ) from None
 
 
 class KeyValuePairsType:
@@ -420,5 +463,5 @@ class KeyValuePairsType:
                         pass
                 out[k] = pv
         except Exception as e:
-            raise ArgumentTypeError(e)
+            raise ArgumentTypeError() from e
         return out
